<?php
class UserController extends Controller
{    
	/**
	 * Displays a particular model.
     * 
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{       
        Yii::import('application.modules.faam.vendors.ArrayToList');
        $model = $this->loadModel($id);
        if (is_array($model->permissions)) {
            $list = new ArrayToList;
            $model->permissions = $list->makeUList($model->permissions);
        }
		$this->render('view',array(
			'model'=>$model,
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{       
        $model = new User;
        $groups = Group::model()->findAll();        
        
        // if there is no groups, we need to create it first
        if (empty($groups)) {
            Yii::app()->user->setFlash('error','You need to have at least one group first.');
            $this->redirect(array('group/create'));
        }

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['User'])) {
            
            $_POST['User']['permissions'] = !isset($_POST['User']['permissions']) ? NULL : $_POST['User']['permissions'];
			$model->attributes=$_POST['User'];
            $model->setAttribute('permissions', $_POST['User']['permissions']);
			if($model->save())
				$this->redirect(array('index'));
		}

		$this->render('create',array(
			'model'=>$model,
            'groups'=>$groups,
            'permissions'=>Yii::app()->metadata->getAll()
		));
	}

	/**
	 * Changes a permissions of a user.
	 * If update is successful, the browser will be redirected to the 'view' page.
     * 
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionChangePermissions($id)
	{   
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['User']))
		{           
            $_POST['User']['permissions'] = !isset($_POST['User']['permissions']) ? NULL : $_POST['User']['permissions'];            
			$model->attributes=$_POST['User'];
            $model->setAttribute('permissions', $_POST['User']['permissions']);
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('change_permissions',array(
			'model'=>$model,
            'groups'=>Group::model()->findAll(),
            'permissions'=>Yii::app()->metadata->getAll()
		));
	}

	/**
	 * Updates a user password.
	 * If update is successful, the browser will be redirected to the 'view' page.
     * 
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionChangePassword($id)
	{   
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['User']))
		{                    
			$model->scenario='changePassword';
            $model->attributes=$_POST['User'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('change_password',array(
			'model'=>$model
		));
	} 
    
	/**
	 * Updates a user email.
	 * If update is successful, the browser will be redirected to the 'view' page.
     * 
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionChangeEmail($id)
	{   
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		$this->performAjaxValidation($model);

		if(isset($_POST['User']))
		{                    
			$model->scenario='changeEmail';
            $model->attributes=$_POST['User'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id));
		}

		$this->render('change_email',array(
			'model'=>$model
		));
	}     
    
	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
     * 
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		if(Yii::app()->request->isPostRequest) {
			// we only allow deletion via POST request
			$this->loadModel($id)->delete();

			// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
			if(!isset($_GET['ajax']))
				$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('index'));
		} else {
			throw new CHttpException(400,'Invalid request. Please do not repeat this request again.');
        }
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{       
        $criteria = new CDbCriteria();
        $count=User::model()->count($criteria);
        $pages=new CPagination($count);       
        
        // results per page
        $pages->pageSize=10;
        $pages->applyLimit($criteria);
        $users=User::model()->findAll($criteria);

        $this->render('index', array(
            'users' => $users,
            'pages' => $pages
        )); 
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
     * 
	 * @param integer the ID of the model to be loaded
	 */
	public function loadModel($id)
	{
		$model=User::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
     * 
	 * @param CModel the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='user-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}     
}
